.. hide-toc: true

HydroRollCore 
==============

.. include:: ../../README.rst
   :start-after: .. index-start
   :end-before: .. index-end


.. toctree::
    :hidden:


    快速开始 <pages/quick-start.rst>


.. toctree::
   :caption: Development
   :hidden:


    贡献指南 <pages/contributing.rst>
    变更日志 <changelog>
    COPYING <COPYING>